@@ -1,3 +1,6 @@
+use crate::data::Data;
+use crate::metadata::Metadata;
+
 // Adapted from https://github.com/rust-lang/rust/blob/0f6f2d68/library/test/src/stats.rs#L259-L281
 pub fn percentile_of_sorted(sorted_samples: &Vec<f64>, pct: f64) -> f64 {
     assert!(!sorted_samples.is_empty());
@@ -20,3 +23,12 @@ pub fn percentile_of_sorted(sorted_samples: &Vec<f64>, pct: f64) -> f64 {
     let hi = sorted_samples[n + 1];
     lo + (hi - lo) * d
 }
+
+pub fn pct_keyspace_sampled(metadata: &Metadata, data: &Data) -> f64 {
+    let pct_of_keyspace_sampled = data.sample_count() as f64 / metadata.total_keys as f64;
+    if pct_of_keyspace_sampled > 100_f64 {
+        100_f64
+    } else {
+        pct_of_keyspace_sampled
+    }
+}
