@@ -2,6 +2,7 @@ use std::str::FromStr;
 
 use crate::config::Config;
 use crate::data::Data;
+use crate::metadata::Metadata;
 
 mod stdout_table;
 
@@ -25,11 +26,11 @@ impl FromStr for OutputMode {
 }
 
 // Eventually, there will be more OutputMode options, and this will make more sense
-pub fn output(config: &Config, data: &Data) {
+pub fn output(config: &Config, metadata: &Metadata, data: &Data) {
     use OutputMode::*;
 
     match config.output_mode {
-        StdoutTable => stdout_table::stdout_table(config, data),
+        StdoutTable => stdout_table::stdout_table(config, metadata, data),
     }
 }
 
